﻿using System.Globalization;
using CsvHelper;
using CsvHelper.Configuration;
using DataLoader.Model;

namespace DataLoaderSqLite;

public class DataImporter
{        
    
    private const string AircraftsCsvFileName = @"Aircrafts.csv";

    private const string AirCrashesCsvFileName = @"AirCrashes.csv";

    private const string CarriersCsvFileName = @"Carriers.csv"; 
    public void LoadData()
    {
        using var dbContext = new DatabaseContext();
        dbContext.Carriers.AddRange(ImportFromCsv<Carrier>(CarriersCsvFileName));

        var aircrats = ImportFromCsv<RawAircraft>(AircraftsCsvFileName).ToAircrafts()
            .DistinctBy(x => x.AircraftType)
            .ToList();
        dbContext.Aircrafts.AddRange(aircrats);

        dbContext.AirCrashes.AddRange(ImportFromCsv<RawAirCrash>(AirCrashesCsvFileName).ToAirCrashes());
        dbContext.SaveChanges();
    }

    private static IList<T> ImportFromCsv<T>(string filename) where T: new()
    {
        IList<T> items;
        var path = Path.Combine(Path.GetDirectoryName(AppDomain.CurrentDomain.BaseDirectory)!, @"Resources");
        var filePath = Path.Combine(path, filename);
        using (TextReader reader = File.OpenText(filePath))
        {
            using (var csv = new CsvReader(reader, new CsvConfiguration(CultureInfo.InvariantCulture) {HasHeaderRecord = false}))
            {
                items = csv.GetRecords<T>().ToList();
            }
        }
        return items;
    }
}