﻿using DataLoader.Model;
using Microsoft.EntityFrameworkCore;

namespace DataLoaderSqLite
{
    public class DatabaseContext : DbContext
    {
        public DbSet<AirCrash> AirCrashes { get; set; }
        public DbSet<Aircraft> Aircrafts { get; set; }
        public DbSet<Carrier> Carriers { get; set; }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            modelBuilder.Entity<AirCrash>().ToTable("AirCrashes");
            modelBuilder.Entity<Aircraft>().ToTable("Aircrafts");
            modelBuilder.Entity<Carrier>().ToTable("Carriers");

            modelBuilder.Entity<Aircraft>()
                .HasKey(x => x.AircraftType);

            modelBuilder.Entity<Carrier>()
                .HasKey(x => x.Code);

        }

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            var dir=  AppContext.BaseDirectory.Substring(0, AppContext.BaseDirectory.IndexOf("bin"));
            var dataFile = Path.Combine(dir, "Data");
            dataFile = Path.Combine(dataFile, "Database.sqlite");
            optionsBuilder.UseSqlite($@"Data Source={dataFile}");
            optionsBuilder.EnableSensitiveDataLogging();
            optionsBuilder.EnableDetailedErrors();
            base.OnConfiguring(optionsBuilder);
        }

    }
}
